@minimal @ci_job
Feature: Create, read, update and delete a Security Groups for OpenStack as "Authenticated User"

  @api @javascript
  Scenario: Create a security group
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/security_group/add"
    And I should see the heading "Add OpenStack security group"
    And I enter "{{ security_group_name_operate }}" for "Security group name"
    And I enter "{{ security_group_description }}" for "Description"
    And I press "Save"
    And I wait for AJAX to finish
    Then the url should match "/clouds/openstack/{{ cloud_context }}/security_group/"
    And I should see the success message "has been created"
    And I should see the success message "Setup the IP permissions"
    And I should see the link "{{ security_group_name_operate }}" in the success_message
    And I should see neither error nor warning messages

  @api @javascript
  Scenario: Read the security group
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/security_group"
    And I click "Refresh"
    And I should see the link "{{ security_group_name_operate }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ security_group_name_operate }}"
    Then the url should match "/clouds/openstack/{{ cloud_context }}/security_group/"
    And I should see "{{ security_group_name_operate }}"
    And I should see "{{ security_group_description }}"
    And I press "Others"
    And I should see "{{ drupal_user_name }}" in the "Authored by"
    And I should see neither error nor warning messages

  @wip # Remove @wip tag once Cloud Orchestrator support select function
  @api @javascript
  Scenario: Add a rules to the security group
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/security_group"
    And I click "Refresh"
    And I should see the link "{{ security_group_name_operate }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ security_group_name_operate }}"
    Then the url should match "/clouds/openstack/{{ cloud_context }}/security_group/"
    And I click "Edit"
    Then the url should match "/edit"
    # Add a rule to Inbound rules
    And I fill in "{{ security_group_port }}" for "From Port" in the row "0" in the "Inbound rules"
    And I fill in "{{ security_group_port }}" for "To Port" in the row "0" in the "Inbound rules"
    # Currently Cloud Orchestrator does not support select function
    And I select "{{ security_group_source }}" from "Source" in the row "0" in the "Inbound rules"
    And I fill in "{{ security_group_ip }}" for "CIDR IP" in the row "0" in the "Inbound rules"
    And I fill in "{{ security_group_description }}" for "Description" in the row "0" in the "Inbound rules"
    # Add a rule to Outbound rules
    And I fill in "{{ security_group_port }}" for "From Port" in the row "1" in the "Outbound rules"
    And I fill in "{{ security_group_port }}" for "To Port" in the row "1" in the "Outbound rules"
    # Currently Cloud Orchestrator does not support select function
    And I select "{{ security_group_source }}" from "Source" in the row "1" in the "Outbound rules"
    And I fill in "{{ security_group_ip }}" for "CIDR IP" in the row "1" in the "Outbound rules"
    And I fill in "{{ security_group_description }}" for "Description" in the row "1" in the "Outbound rules"
    And I press "Save"
    And I wait for AJAX to finish
    And I wait {{ wait }} milliseconds
    Then I visit "/clouds/openstack/{{ cloud_context }}/security_group"
    And I click "Refresh"
    And I should see the link "{{ security_group_name_operate }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ security_group_name_operate }}"
    And I should see "{{ security_group_port }}" in the "{{ security_group_description }}" row in the "Inbound rules"
    And I should see "{{ security_group_port }}" in the "{{ security_group_description }}" row in the "Inbound rules"
    And I should see "{{ security_group_ip }}" in the "{{ security_group_description }}" row in the "Inbound rules"
    And I should see "{{ security_group_port }}" in the "{{ security_group_description }}" row in the "Outbound rules"
    And I should see "{{ security_group_port }}" in the "{{ security_group_description }}" row in the "Outbound rules"
    And I should see "{{ security_group_ip }}" in the "{{ security_group_description }}" row in the "Outbound rules"
    And I press "Others"
    And I should see "{{ drupal_user_name }}" in the "Authored by"

  @wip # Remove @wip tag once Cloud Orchestrator support select function
  @api @javascript
  Scenario: Remove a rule from the security group
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/security_group"
    And I click "Refresh"
    And I should see the link "{{ security_group_name_operate }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ security_group_name_operate }}"
    Then the url should match "/clouds/openstack/{{ cloud_context }}/security_group/"
    # Confirm rule in Outbound rules
    And I should see "{{ security_group_ip }}" in the "Outbound rules"
    And I click "Edit"
    Then the url should match "/edit"
    And I follow "Remove rule" in a row with "{{ security_group_ip }}" set in "CIDR IP" in the "Outbound rules"
    And I press "Save"
    And I wait for AJAX to finish
    And I wait {{ wait }} milliseconds
    Then I visit "/clouds/openstack/{{ cloud_context }}/security_group"
    And I click "Refresh"
    And I should see the link "{{ security_group_name_operate }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ security_group_name_operate }}"
    And I should not see "{{ security_group_ip }}" in the "Outbound rules"

  @api @javascript
  Scenario: Delete the security group
    Given I am logged in as user "{{ drupal_user_name }}"
    When I visit "/clouds/openstack/{{ cloud_context }}/security_group"
    And I click "Refresh"
    And I should see the link "{{ security_group_name_operate }}"
    And I wait {{ wait }} milliseconds
    And I click "{{ security_group_name_operate }}"
    Then the url should match "/clouds/openstack/{{ cloud_context }}/security_group/"
    And I click "Delete"
    Then the url should match "/delete"
    And I press "Delete"
    Then I should be on "/clouds/openstack/{{ cloud_context }}/security_group"
    And I should see the success message "has been deleted"
    And I should see neither error nor warning messages
    And I click "Refresh"
    And I should not see the link "{{ security_group_name_operate }}"
